Attribute VB_Name = "mIni"
'---------------------------------------------------------------------------------------
' Module    : mIni
' DateTime  : 18/10/2007 01:32
' Author    : Cobein
' Mail      : cobein27@hotmail.com
' Purpose   : Read and write settings on an INI file.
' Requirements: none
'---------------------------------------------------------------------------------------
Option Explicit

Private Const MAX_STRING_LENGTH As Long = 256

Private Declare Function GetPrivateProfileString Lib "kernel32" Alias "GetPrivateProfileStringA" ( _
    ByVal lpApplicationName As String, _
    ByVal lpKeyName As Any, _
    ByVal lpDefault As String, _
    ByVal lpReturnedString As String, _
    ByVal nSize As Long, _
    ByVal lpFileName As String) As Long
Private Declare Function WritePrivateProfileString Lib "kernel32" Alias "WritePrivateProfileStringA" ( _
    ByVal lpApplicationName As String, _
    ByVal lpKeyName As Any, _
    ByVal lpString As Any, _
    ByVal lpFileName As String) As Long

Private m_sPath As String
Private m_sFilename As String

Public Function Init()
    m_sPath = IIf(Right(App.Path, 1) = "\", App.Path, App.Path & "\")
    m_sFilename = App.EXEName & ".ini"
End Function

Public Property Let Filename(ByVal sFilename As String)
    If sFilename = vbNullString Then Exit Property
    m_sFilename = sFilename
End Property

Public Property Get Filename() As String
    Filename = m_sFilename
End Property

Public Property Let Path(ByVal sPath As String)
    If sPath = vbNullString Then Exit Property
    m_sPath = IIf(Right(sPath, 1) = "\", sPath, sPath & "\")
    m_sPath = sPath
End Property

Public Property Get Path() As String
    Path = m_sPath
End Property

Public Function WriteData( _
       ByVal sSection As String, _
       ByVal sKeyName As String, _
       ByVal sValue As String) As Boolean
    
    If sSection = vbNullString Or _
       sKeyName = vbNullString Or _
       sValue = vbNullString Then
        WriteData = False
        Exit Function
    End If
    
    WriteData = Not CBool( _
       WritePrivateProfileString( _
       sSection, _
       sKeyName, _
       sValue, _
       m_sPath & m_sFilename) = 0)

End Function

Public Function ReadData( _
       ByVal sSection As String, _
       ByVal sKeyName As String, _
       Optional sDefault As String = vbNullString) As String
       
    Dim lSize As Long
    Dim sBuffer As String
        
    If sSection = vbNullString Or _
       sKeyName = vbNullString Then
        ReadData = sDefault
        Exit Function
    End If
    
    sBuffer = Space(MAX_STRING_LENGTH)
  
    lSize = GetPrivateProfileString( _
       sSection, _
       sKeyName, _
       sDefault, _
       sBuffer, _
       MAX_STRING_LENGTH, _
       m_sPath & m_sFilename)

    If lSize = 0 Then
        ReadData = sDefault
    Else
        ReadData = Left(sBuffer, lSize)
    End If
    
End Function
